@@ -17,10 +17,9 @@ import pandas as pd
 import numpy as np
 import dash_bootstrap_components as dbc
 import time
-import shap
 import dash_editor_components
 import socket
 from contextlib import closing
+import requests
 
-import xgboost
 import shap
